Crate radiate_utils

Crate radiate_utils 

Modules

dtype
dtype_names
value

Macros

impl_float_scalar
impl_integer
intern
intern_str_cache

Structs

Distribution
LruCache
MinMax
Quantile
Running quantile estimator using the P² algorithm.
Shape
Slope
SmallStr
SortedBuffer
Statistic
Strides
Tensor
Row-major tensor structure. The data is stored in a contiguous vector, and the shape and strides are used to interpret the data.
VersionedCounts
A reusable counter keyed by usize with O(1) “clear” between sessions.
WindowBuffer

Enums

AnyValue
DataType
Value

Constants

STR_CACHE
STR_INTERN_CACHE

Traits

DType
Float
Integer
Primitive
ToSnakeCase

Functions

dedup_slice
intern_kv_pair
is_str_cached
is_str_interned
pow_anyvalue
short_type_name
try_get_interned_str